@@ -72,7 +72,7 @@ class IgorIBWReader(Reader):
 
             for channel in range(images.shape[-1]):
                 #Convert it to sidpy dataset object
-                data_set = sid.Dataset.from_array(images[:,:,channel], title=chan_labels[channel])
+                data_set = sid.Dataset.from_array(images[:,:,channel], name=chan_labels[channel])
                 data_set.data_type = 'Image'
 
                 #Add quantity and units
@@ -121,7 +121,7 @@ class IgorIBWReader(Reader):
                 # For now, we'll shove the Z sensor data into the spectroscopic values.
 
                 #convert to sidpy dataset
-                data_set = sid.Dataset.from_array((images[:,channel,0]), title=chan_labels[channel])
+                data_set = sid.Dataset.from_array((images[:,channel,0]), name=chan_labels[channel])
 
                 if verbose:
                     print('Channel {} and spec_data is {}'.format(channel, spec_data))
@@ -135,7 +135,7 @@ class IgorIBWReader(Reader):
                                                         dimension_type='spectral'))
 
                 #append metadata
-                data_set.data_type = 'line_plot'
+                data_set.data_type = 'SPECTRUM'
                 data_set.original_metadata = parm_dict
 
                 #Add dataset to list
